==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/outputs/ClassificationJobS3JobDefinitionBucketCriteria.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property excludes The property- or tag-based conditions that determine which S3 buckets to exclude from the analysis. (documented below)
 * @property includes The property- or tag-based conditions that determine which S3 buckets to include in the analysis. (documented below)
 */
public data class ClassificationJobS3JobDefinitionBucketCriteria(
    public val excludes: ClassificationJobS3JobDefinitionBucketCriteriaExcludes? = null,
    public val includes: ClassificationJobS3JobDefinitionBucketCriteriaIncludes? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.macie2.outputs.ClassificationJobS3JobDefinitionBucketCriteria):
            ClassificationJobS3JobDefinitionBucketCriteria =
            ClassificationJobS3JobDefinitionBucketCriteria(
                excludes = javaType.excludes().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.macie2.kotlin.outputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludes.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                includes = javaType.includes().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.macie2.kotlin.outputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludes.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/macie2/kotlin/outputs/ClassificationJobS3JobDefinitionBucketCriteria.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.macie2.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property excludes The property- or tag-based conditions that determine which S3 buckets to exclude from the analysis. (documented below)
 * @property includes The property- or tag-based conditions that determine which S3 buckets to include in the analysis. (documented below)
 */
public data class ClassificationJobS3JobDefinitionBucketCriteria(
    public val excludes: ClassificationJobS3JobDefinitionBucketCriteriaExcludes? = null,
    public val includes: ClassificationJobS3JobDefinitionBucketCriteriaIncludes? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.macie2.outputs.ClassificationJobS3JobDefinitionBucketCriteria): ClassificationJobS3JobDefinitionBucketCriteria =
            ClassificationJobS3JobDefinitionBucketCriteria(
                excludes = javaType.excludes().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.macie2.kotlin.outputs.ClassificationJobS3JobDefinitionBucketCriteriaExcludes.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                includes = javaType.includes().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.macie2.kotlin.outputs.ClassificationJobS3JobDefinitionBucketCriteriaIncludes.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
